@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.214 2004/12/17 06:51:47 lav Exp $ */
+/* $Id: commands.cc,v 1.218 2005/04/04 09:59:44 lav Exp $ */
 
 #include <config.h>
 
@@ -674,10 +674,16 @@ Job *CmdExec::builtin_lftp()
 	 cmd=acmd;
 	 break;
       case('c'):
-	 acmd=string_alloca(4+strlen(optarg));
-	 sprintf(acmd,"%s\n\n",optarg);
+      {
+	 int cmd_start=args->getindex()-1;
+	 char *c = (args->count()==cmd_start+1
+		      ? args->Combine(cmd_start) : args->CombineQuoted(cmd_start));
+	 acmd=string_alloca(4+strlen(c));
+	 sprintf(acmd,"%s\n\n",c);
 	 cmd=acmd;
+	 xfree(c);
 	 break;
+      }
       case('d'):
 	 debug=true;
 	 break;
@@ -1328,18 +1334,18 @@ const char *FileSetOutput::parse_argv(ArgV *a)
       {"dirsfirst", no_argument,0,'D'},
 
       {"sort", required_argument,0, 0},
+      {"reverse",no_argument,0,'r'},
       {"user", no_argument,0, 0},
       {"group", no_argument,0, 0},
       {"perms", no_argument,0, 0},
       {"date", no_argument,0, 0},
       {"linkcount", no_argument,0, 0},
       {"links", no_argument,0, 0},
-      {0, no_argument, 0, 'S'}, // sort by size
       {0,0,0,0}
    };
 
    int opt, longopt;
-   while((opt=a->getopt_long(":1BdFhiklqsDIS", cls_options, &longopt))!=EOF)
+   while((opt=a->getopt_long(":1BdFhiklqsDISrt", cls_options, &longopt))!=EOF)
    {
       switch(opt) {
       case 0:
@@ -1410,6 +1416,12 @@ const char *FileSetOutput::parse_argv(ArgV *a)
       case('S'):
 	 sort = FileSet::BYSIZE;
 	 break;
+      case('t'):
+	 sort = FileSet::BYDATE;
+	 break;
+      case('r'):
+	 sort_reverse = true;
+	 break;
 
       default:
 	 /* silly getopt won't give us its error instead of printing it, oh well.
@@ -2406,7 +2418,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("Lftp | Version %s | Copyright (c) 1996-2004 Alexander V. Lukyanov\n"),VERSION);
+      _("Lftp | Version %s | Copyright (c) 1996-2005 Alexander V. Lukyanov\n"),VERSION);
    printf(
       _("This is free software with ABSOLUTELY NO WARRANTY. See COPYING for details.\n"));
    printf(
